---
slug: /error-code-6000-6999
---

# 6000 ~ 6999

This range represents the error codes of the object layer, including transaction, MVCC, and clog errors.

## ERROR 6001 (25000) : Transaction set changed during the execution

* seekdb error code: 6001

* Cause: An update request requires reading data before updating. If the data changes before the update, this error code is returned to the upper layer, and the operation is retried.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6002 (25000) : Transaction idle timeout occurred, please rollback the transaction, set the variable ob_trx_idle_timeout to a larger value and then restart the transaction

* seekdb error code: 6278

* Compatible MySQL error code: 6002

## ERROR 6002 (25000) : transaction needs rollback

* seekdb error code: 6224

* Compatible MySQL error code: 6002

## ERROR 6002 (25000) : Transaction exiting

* seekdb error code: 6223

* Compatible MySQL error code: 6002

## ERROR 6002 (25000) : transaction context count reach limit

* seekdb error code: 6234

* Compatible MySQL error code: 6002

## ERROR 6002 (HY000) : Transaction context does not exist

* seekdb error code: 6213

* Compatible MySQL error code: 6002

## ERROR 6002 (25000) : Partition is frozen

* seekdb error code: 6214

* Compatible MySQL error code: 6002

## ERROR 6002 (25000) : Transaction is killed

* seekdb error code: 6211

* Compatible MySQL error code: 6002

## ERROR 6005 (HY000) : Try lock row conflict

* seekdb error code: 6005

* Cause: The lock for an update operation fails. This error code is returned to the upper layer, and the operation is retried.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6201 (25000) : Clock out of order

* seekdb error code: 6201

* Cause: The background clock thread runs every 1 ms. If the time interval between two consecutive runs exceeds 10 ms, this error code is returned.

* Solution: If this error frequently occurs, check whether the machine load is too high or the machine clock is unstable.

## ERROR 6203 (25000) : Mask set has no node

* seekdb error code: 6203

* Cause: A node does not exist in the mask set container.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6204 (HY000) : Transaction has been decided

* seekdb error code: 6204

* Cause: The transaction has been initiated for submission.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6205 (HY000) : Transaction state invalid

* seekdb error code: 6205

* Cause: The transaction state machine is abnormal.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6206 (HY000) : Transaction state not changed

* seekdb error code: 6206

* Cause: The state machine does not need to change.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6208 (HY000) : Transaction message invalid

* seekdb error code: 6208

* Cause: The transaction message is invalid.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6209 (HY000) : Transaction message type invalid

* seekdb error code: 6209

* Cause: The message type is invalid.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6215 (HY000) : Partition is not frozen

* seekdb error code: 6215

* Cause: This error code is invalid.

* Solution: No action is required.

## ERROR 6219 (HY000) : Transaction invalid log type

* seekdb error code: 6219

* Cause: The log type is invalid.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6220 (HY000) : SQL sequence illegal

* seekdb error code: 6220

* Cause: The SQL statement sequence is invalid.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6221 (HY000) : Transaction context cannot be killed

* seekdb error code: 6221

* Cause: The current transaction context cannot be terminated.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6222 (HY000) : Transaction state unknown

* seekdb error code: 6222

* Cause: The transaction state is unknown.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6227 (HY000) : Partition is not stopped

* seekdb error code: 6227

* Cause: The partition has not been set to the stopped state.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6228 (HY000) : Partition has been stopped

* seekdb error code: 6228

* Cause: The partition has been set to the stopped state.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6229 (HY000) : Partition has been blocked

* seekdb error code: 6229

* Cause: The partition has been set to the blocked state.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6232 (HY000) : Partition is splitting

* seekdb error code: 6232

* Cause: The partition is splitting. The upper layer is notified and the operation is retried.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6233 (HY000) : Transaction has been commited

* seekdb error code: 6233

* Cause: The transaction has been committed.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6235 (25000) : can't serialize access for this transaction

* seekdb error code: 6235

* Cause: The transaction cannot be serialized.

* Solution: The client must roll back the transaction and re-execute it.

## ERROR 6236 (HY000) : transaction weak read version is not ready

* seekdb error code: 6236

* Cause: The weak-consistency read version cannot be generated.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6240 (HY000) : pg partition not exist

* seekdb error code: 6240

* Error reason: The partition group does not exist.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6241 (HY000) : transaction statement need retry

* seekdb error code: 6241

* Error reason: The statement needs to be retried. The current transaction may be writing logs or requesting a follower.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6243 (HY000) : local schema is not new enough, replaying logs of user table from standby cluster needs to wait for schema refreshing

* seekdb error code: 6243

* Error reason: The local schema is not new enough. Log replaying needs to be retried.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6244 (HY000) : out of transaction threshold

* seekdb error code: 6244

* Error reason: The transaction size exceeds the `_max_trx_size` limit.

* Solution: Adjust the transaction size.

## ERROR 6256 (HY000) : Row has not been locked

* seekdb error code: 6256

* Error reason: The row lock has not been acquired.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6257 (HY000) : Empty partition group

* seekdb error code: 6257

* Error reason: The partition list of the partition group is empty.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6265 (HY000) : object lock does not exist

* seekdb error code: 6265

* Error reason: The lock for the table does not exist.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6266 (HY000) : object lock exists

* seekdb error code: 6266

* Error reason: The lock for the table already exists. This indicates a duplicate lock operation.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6267 (HY000) : Try lock object conflict

* seekdb error code: 6267

* Error reason: A lock conflict occurred during the lock operation.

* Solution: Reserved error code. Not enabled yet.

## ERROR 6268 (HY000) : No log callbacks available

* seekdb error code: 6268

* Error reason: The number of uncallbacked logs for a single transaction has reached the upper limit, and no more logs can be submitted.

* Solution: Retry or wait for the log layer to callback.

## ERROR 6275 (HY000) : object lock not completed, and can not unlock

* seekdb error code: 6275

* Error reason: The table lock transaction has not completed when unlocking the DDL.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6276 (HY000) : there is an unlock operation doing, unlock conflict

* seekdb error code: 6276

* Error reason: Another unlock operation is ongoing when unlocking the DDL.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6277 (HY000) : scn is out of bounds of memtable

* seekdb error code: 6277

* Error reason: The SCN set for the MemTable exceeds its boundary limit.

* Solution: Internal error code. If the error is returned as ERROR, contact technical support for assistance. If the error is returned as WARN, it indicates a normal situation.

## ERROR 6280 (HY000) : Transaction cost too much without commit or rollback

* seekdb error code: 6280
* Error reason: The transaction has been alive for a long time, and the row lock cannot be released.
* Solution: Analyze the business scenario to determine whether the long transaction meets the expected requirements.

## ERROR 6281 (HY000) : Transaction commit cost too much

* seekdb error code: 6281
* Error reason: The transaction commit or rollback takes too long, and the transaction commit is abnormal.
* Solution: Contact technical support for assistance.

## ERROR 6302 (HY000) : log scan runnable thread stop

* seekdb error code: 6302

* Error reason: Internal error. During the seekdb restart, the process receives a signal such as `kill -15`, causing the process to exit. The `observer.log` file will display the above error code.

* Solution: Restart the process.

## ERROR 6303 (HY000) : no log ever scanned

* seekdb error code: 6303

* Error reason: Internal error. The Liboblog cannot find the corresponding partition logs on the corresponding seekdb.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6308 (HY000) : external executor handle do not finish

* seekdb error code: 6308

* Error reason: Internal error. When Liboblog locates the Partition based on the startup timestamp to pull the `start_log_id` from seekdb, it supports the resume feature. If a partition is not processed in this RPC, Liboblog will return this error code to execute the subsequent logic.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6309 (HY000) : cursor not exist

* seekdb error code: 6309

* Error reason: Internal error. The corresponding `log_id` cannot be queried in the Index Log Storage.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6310 (HY000) : stream not exist

* seekdb error code: 6310

* Error reason: Internal error. If the stream ID in the request executed by Liboblog cannot be found in the memory of seekdb, this error code will be returned.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6311 (HY000) : stream busy

* seekdb error code: 6311

* Error reason: Internal error. If Liboblog executes two RPC requests for the same stream, this error code will be returned.

* Solution: Internal error code. Contact technical support for assistance.

## ## ERROR 6312 (HY000) : file recycled

* seekdb error code: 6312

* Error reason: Internal error. The `CLog File` read based on the information recorded in the `Index Log` has been recycled, and this error code will be returned.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6313 (HY000) : replay eagain cost too much time

* seekdb error code: 6313

* Error reason: Internal error. The confirmed logs are submitted to the replay engine, but the replay engine returns OB_EAGAIN (indicating that the operation needs to be retried) for a long time due to some reasons, and this error code will be returned.

* Solution: Internal error code. Contact technical support for assistance.

## ERROR 6317 (HY000) : alloc log id need retry

* seekdb error code: 6317

* Error reason: Internal error. This error occurs when the number of concurrent transactions exceeds the processing capacity of the log system. The transaction engine will retry the transaction.

* Solution: This is an internal error code. Contact technical support for assistance.

## ERROR 6321 (HY000) : ob invalid batch size

* seekdb error code: 6321

* Error reason: Internal error.

* Solution: This is an internal error code. Contact technical support for assistance.

## ERROR 6322 (HY000) : ob clog slide timeout

* seekdb error code: 6322

* Error reason: Internal error. This error occurs when the time taken to replay confirmed logs from the log system to the replay engine for a single partition exceeds the system's predefined threshold. The processing of this partition is stopped, and the next partition's tasks are started.

* Solution: This is an internal error code. Contact technical support for assistance.

## ERROR 6325 (HY000) : ob clog disk hang

* seekdb error code: 6325

* Error reason: The Clog log disk is hung.

* Solution: Check the disk status and database load.

## ERROR 6329 (HY000) : pdml sql need retry under sequence number reorder

* seekdb error code: 6329

* Error reason: The PDML query statement needs to be retried under sequence number reordering.

* Solution: Retry the PDML query statement after sequence number reordering.

## ERROR 6330 (HY000) : user data disk is almost full

* seekdb error code: 6330

* Error reason: The user data disk is almost full.
* Solution: Clear or expand the user data disk space to ensure sufficient storage for user data.

## ERROR 6400(HY000) : tablet_freeze timeout

* seekdb error code: 6400
* Error reason: Partition-level freezing.
* Solution: Contact technical support for assistance.